from typing import Any, List, Dict
from enum import Enum

from common import Message, Context

from pydantic import BaseModel


class WebhookState(Enum):
    WEBHOOK_STATE_UNSPECIFIED = "WEBHOOK_STATE_UNSPECIFIED"
    WEBHOOK_STATE_ENABLED = "WEBHOOK_STATE_ENABLED"
    WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING = "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"


class Type(Enum):
    TYPE_UNSPECIFIED = "TYPE_UNSPECIFIED"
    EXAMPLE = "EXAMPLE"


class Part(BaseModel):
    text: str
    entityType: str | None
    alias: str | None
    userDefined: bool | None


class TrainingPhrase(BaseModel):
    name: str
    type: Type
    parts: List[Part]
    timesAddedCount: int | None


class FollowupIntentInfo(BaseModel):
    followupIntentName: str
    parentFollowupIntentName: str


class Intent(BaseModel):
    displayName: str
    name: str | None
    webhookState: WebhookState | None
    priority: int | None
    isFallback: bool | None
    mlDisabled: bool | None
    liveAgentHandoff: bool | None
    endInteraction: bool | None
    inputContextNames: List[str] | None
    events: List[str] | None
    trainingPhrases: List[TrainingPhrase] | None
    action: str | None
    outputContexts: List[Context] | None
    resetContexts: bool | None
    # https://cloud.google.com/dialogflow/es/docs/reference/rest/v2/projects.agent.intents#Intent.Parameter
    parameters: List[dict] | None
    messages: List[Message] | None
    defaultResponsePlatforms: List[Any] | None
    rootFollowupIntentName: str | None
    parentFollowupIntentName: str | None
    followupIntentInfo: List[FollowupIntentInfo] | None

    class Config:
        use_enum_values = True


class Sentiment(BaseModel):
    score: int
    magnitude: int


class SentimentAnalysisResult(BaseModel):
    queryTextSentiment: Sentiment


class QueryResult(BaseModel):
    """https://cloud.google.com/dialogflow/es/docs/reference/rest/v2/DetectIntentResponse#QueryResult"""
    queryText: str
    # language enum here, https://cloud.google.com/dialogflow/es/docs/reference/language
    languageCode: str
    speechRecognitionConfidence: int | None
    action: str | None
    parameters: Dict[str, dict | str | int | bool | list] | None
    allRequiredParamsPresent: bool
    cancelsSlotFilling: bool | None
    fulfillmentText: str | None
    fulfillmentMessages: List[Message] | None
    webhookSource: str | None
    webhookPayload: dict | None
    outputContexts: List[Context] | None
    intent: Intent
    intentDetectionConfidence: int
    diagnosticInfo: dict
    sentimentAnalysisResult: SentimentAnalysisResult | None

class OriginalDetectIntentRequest(BaseModel):
    source: str | None
    version: str | None
    payload: Dict[str, dict] | None

class WebhookRequest(BaseModel):
    """
    """
    session: str
    responseId: str
    queryResult: QueryResult
    originalDetectIntentRequest: OriginalDetectIntentRequest | None


request = WebhookRequest.parse_file("tests\\request-01.json")

print(request)




from typing import List, Dict
from enum import Enum

from common import Message, Context

from pydantic import BaseModel

class EntityOverrideMode(Enum):
    ENTITY_OVERRIDE_MODE_UNSPECIFIED= "ENTITY_OVERRIDE_MODE_UNSPECIFIED"
    ENTITY_OVERRIDE_MODE_OVERRIDE = "ENTITY_OVERRIDE_MODE_OVERRIDE"
    ENTITY_OVERRIDE_MODE_SUPPLEMENT = "ENTITY_OVERRIDE_MODE_SUPPLEMENT"

class EventInput(BaseModel):
    name: str | None
    parameters: Dict[str, str |int |bool | list | dict] | None
    languageCode: str | None

class Entity(BaseModel):
    value: str
    synonyms: List[str]

class SessionEntityType(BaseModel):
    name: str
    entityOverrideMode: EntityOverrideMode
    entities: Entity

class WebhookResponse(BaseModel):
    fulfillmentText: str | None
    fulfillmentMessages: List[Message] | None
    source: str | None
    payload: dict | None
    outputContext: List[Context] | None
    followupEventInput: EventInput | None
    sessionEntityTypes: List[SessionEntityType] | None

a = WebhookResponse.construct()
a = a.json(exclude_none=True)
print(a)



from typing import Dict
from enum import Enum

from pydantic import BaseModel


class Platform(Enum):
    PLATFORM_UNSPECIFIED = "PLATFORM_UNSPECIFIED"
    FACEBOOK = "FACEBOOK"
    SLACK = "SLACK"
    TELEGRAM = "TELEGRAM"
    KIK = "KIK"
    SKYPE = "SKYPE"
    LINE = "LINE"
    VIBER = "VIBER"
    ACTIONS_ON_GOOGLE = "ACTIONS_ON_GOOGLE"
    GOOGLE_HANGOUTS = "GOOGLE_HANGOUTS"


class Message(BaseModel):
    platform: Platform | None
    text: dict | None
    image: dict | None
    quickReplies: dict | None
    card: dict | None
    payload: dict | None
    simpleResponses: dict | None
    basicCard: dict | None
    suggestions: dict | None
    linkOutSuggestion: dict | None
    listSelect: dict | None
    carouselSelect: dict | None
    browseCarouselCard: dict | None
    tableCard: dict | None
    mediaContent: dict | None

    class Config:
        use_enum_values = True


class Context(BaseModel):
    name: str
    lifespanCount: int | None
    parameters: Dict[str, str | int | bool | None | list | dict] | None



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dialoghook']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.10.2,<2.0.0']

setup_kwargs = {
    'name': 'dialoghook',
    'version': '0.1.0',
    'description': '',
    'long_description': 'Dialogflow Request and Response Constructs and validators for Webhooks in Dialogflow ES V2 API\n',
    'author': 'aHardReset',
    'author_email': 'ing.aarongaribay@outlook.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/aHardReset/dialoghook',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
